Nautobot ChatOps Documentation

Skip to content

# Nautobot ChatOps

A multi-platform ChatOps bot App for Nautobot.

- Support for multiple chat platforms:
  - Mattermost
  - Microsoft Teams
  - Slack
  - Cisco Webex
- Support for multiple integrations:
  - Cisco ACI
  - AWX / Ansible Tower
  - Arista CloudVision
  - Grafana
  - IPFabric
  - Cisco Meraki
  - Palo Alto Panorama
- Write a command once and run it on every supported platform, including rich content formatting.
- Extensible - other Nautobot plugins can provide additional commands which will be dynamically discovered.
- Automatic generation of basic help menus (accessed via `help`, `/command help`, or `/command sub-command help`).
- Metrics of command usage via the `nautobot_capacity_metrics` plugin.

## Documentation

Full web-based HTML documentation for this app can be found over on the Nautobot Docs website:

- User Guide - Overview, Using the App, Getting Started
- Administrator Guide - How to Install, Configure, Upgrade, or Uninstall the App.
- Developer Guide - Extending the App, Code Reference, Contribution Guide.
- Release Notes / Changelog
- Frequently Asked Questions
- Glossary

## Try it Out

Interested to see Nautobot ChatOps in action? It's currently setup on the Demo Instance and integrated into NTC Slack. You can sign up for that Slack workspace and join the `#nautobot-chat` channel to understand what this bot can do and try it for yourself. You can try these exact chat commands and many more:

### Command: `/nautobot`

### Command: `/nautobot get-devices`

### Command: `/nautobot get-interface-connections`

## Questions

For any questions or comments, please check the FAQ first and feel free to swing by the Network to Code slack channel (channel #nautobot). Sign up here

## Acknowledgements

This project includes code originally written in separate plugins, which have been merged into this project:

- nautobot-plugin-chatops-aci: Thanks @mamullen13316, @smk4664, @ubajze, @whitej6,
- nautobot-plugin-chatops-ansible: Thanks @chipn, @dgjustice, @jeffkala, @jvanderaa, @matt852, @smk4664, @ubajze, @whitej6,
- nautobot-plugin-chatops-arista-cloudvision: Thanks @qduk, @ubajze, @whitej6,
- nautobot-plugin-chatops-grafana: Thanks @jedelman8, @josh-silvas, @nniehoff, @tim-fiola, @ubajze, @whitej6,
- nautobot-plugin-chatops-ipfabric: Thanks @alhogan, @chadell, @chipn, @justinjeffery-ipf, @nniehoff, @pke11y, @scetron, @smk4664, @ubajze, @whitej6,
- nautobot-plugin-chatops-meraki: Thanks @jedelman8, @jeffkala, @qduk, @tim-fiola, @ubajze, @whitej6,
- nautobot-plugin-chatops-panorama: Thanks @FragmentedPacket, @PhillSimonds, @armartirosyan, @itdependsnetworks, @jamesholland-uk, @jdrew82, @matt852, @qduk, @ubajze, @whitej6,